summaryrefslogtreecommitdiff
path: root/python/vyos/config.py
diff options
context:
space:
mode:
Diffstat (limited to 'python/vyos/config.py')
-rw-r--r--python/vyos/config.py25
1 files changed, 18 insertions, 7 deletions
diff --git a/python/vyos/config.py b/python/vyos/config.py
index 7f65a9397..5bd8fb072 100644
--- a/python/vyos/config.py
+++ b/python/vyos/config.py
@@ -65,6 +65,7 @@ In operational mode, all functions return values from the running config.
import os
import re
+import json
import subprocess
import vyos.configtree
@@ -104,12 +105,10 @@ class Config(object):
running_config_text = f.read()
# Session config ("active") only exists in conf mode.
- # Trying to obtain it from op mode will cause a fatal cli-shell-api error.
- # If that happens, we assume that a script is running from op mode and use the running config
- # for the "session config" variable as well.
- try:
+ # In op mode, we'll just use the same running config for both active and session configs.
+ if self.in_session():
session_config_text = self._run([self._cli_shell_api, '--show-working-only', '--show-show-defaults', 'showConfig'])
- except VyOSError:
+ else:
session_config_text = running_config_text
self._session_config = vyos.configtree.ConfigTree(session_config_text)
@@ -224,21 +223,33 @@ class Config(object):
except VyOSError:
return False
- def show_config(self, path='', default=None):
+ def show_config(self, path=[], default=None):
"""
Args:
path (str): Configuration tree path, or empty
default (str): Default value to return
Returns:
str: working configuration
"""
+ if isinstance(path, list):
+ path = " ".join(path)
try:
out = self._run(self._make_command('showConfig', path))
return out
except VyOSError:
return(default)
+ def get_config_dict(self, path=[], effective=False):
+ """
+ Args: path (str list): Configuration tree path, can be empty
+ Returns: a dict representation of the config
+ """
+ res = self.show_config(self._make_path(path))
+ config_tree = vyos.configtree.ConfigTree(res)
+ config_dict = json.loads(config_tree.to_json())
+ return config_dict
+
def is_multi(self, path):
"""
Args:
@@ -224,21 +223,33 @@ class Config(object):
"""
Args:
- path (str): Configuration tree path, or empty
+ path (str list): Configuration tree path, or empty
default (str): Default value to return
Returns: